@@ -15,5 +15,6 @@ def suite():
 
     return test_suite
 
-if __name__ == '__main__':
-    unittest.main(defaultTest='suite')
+
+if __name__ == "__main__":
+    unittest.main(defaultTest="suite")
