@@ -13,9 +13,9 @@ import unittest
 
 def suite():
     """Gather all the tests from this package in a test suite."""
-    import test_gdbm
-    import test_mysql
-    import test_redis
+    from . import test_gdbm
+    from . import test_mysql
+    from . import test_redis
 
     test_suite = unittest.TestSuite()
 
@@ -24,5 +24,6 @@ def suite():
     test_suite.addTest(test_redis.suite())
     return test_suite
 
-if __name__ == '__main__':
-    unittest.main(defaultTest='suite')
+
+if __name__ == "__main__":
+    unittest.main(defaultTest="suite")
