@@ -9,10 +9,10 @@ import unittest
 
 def suite():
     """Gather all the tests from this package in a test suite."""
-    import test_gdbm
-    import test_mysql
-    import test_redis
-    import test_redis_v0
+    from . import test_gdbm
+    from . import test_mysql
+    from . import test_redis
+    from . import test_redis_v0
 
     test_suite = unittest.TestSuite()
 
@@ -22,6 +22,6 @@ def suite():
     test_suite.addTest(test_redis_v0.suite())
     return test_suite
 
-if __name__ == '__main__':
-    unittest.main(defaultTest='suite')
 
+if __name__ == "__main__":
+    unittest.main(defaultTest="suite")
